#
# spec file for package lmms
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Since 42.2 RPM creates a hard requirement on a build time library (libvstbase), the requirement is unnecessary and bad
%global __requires_exclude_from ^%{_libdir}/lmms/.*\\.so$

%bcond_with carla
%bcond_without crippled_stk

Name:           lmms
Version:        1.1.3
Release:        4.20
Summary:        Linux MultiMedia Studio
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Midi
Url:            https://lmms.io/

Source0:        https://github.com/LMMS/lmms/archive/v%{version}.tar.gz
# PATCH-FIX-UPSTREAM Fix wrong comparison logic (from upstream)
Patch1:         lmms-1.1.3-fix-wrong-comparison-logic.patch
# PATCH-FIX-OPENSUSE Patch for providing proper return code in a function
Patch2:         lmms-1.1.0-return.patch
# PATCH-FIX-OPENSUSE Some parts cannot be build because stk misses some files due to legal issues (bnc#761147)
Patch4:         lmms-1.0.0-crippled_stk.patch
Patch5:         lmms-carla.patch
Patch6:         lmms-code-indent.patch
Patch7:         lmms-code-min.patch
Patch8:         lmms-code-macro.patch

BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libstk-devel
BuildRequires:  pkgconfig(QtCore) >= 4.3.0
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtXml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3f) >= 3.0.0
BuildRequires:  pkgconfig(fluidsynth) >= 1.0.7
BuildRequires:  pkgconfig(jack) >= 0.77
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(samplerate) >= 0.1.8
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(sndfile) >= 1.0.11
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(zlib)
%if %{with carla}
# to enable internal Carla plugin host
BuildRequires:  pkgconfig(carla-standalone)
# also needed (contains libcarla_standalone2 library)
BuildRequires:  carla
%endif
# VeSTige needs wineserver for using VST plugins
%ifarch %ix86
Requires:       %{_bindir}/wineserver
Recommends:     %{_bindir}/wine
BuildRequires:  wine
BuildRequires:  wine-devel
%endif
%ifarch x86_64
Requires:       %{_bindir}/wineserver
Recommends:     %{_bindir}/wine
BuildRequires:  wine
%if 0%{?suse_version} == 1230
# Workaround for missing dependency in wine-devel-32bit
BuildRequires:  wine-devel
%endif
BuildRequires:  gcc-c++-32bit
BuildRequires:  wine-devel-32bit
%endif

%description
LMMS is a free cross-platform music studio which allows you to produce music
with your computer. This includes the creation of melodies and beats, the
synthesis and mixing of sounds, and arranging of samples.

%package devel
Summary:        Headers to create LMMS plugins
Group:          Development/Libraries/C and C++

%description devel
Headers that provide access to the LMMS features. Install it if you plan to
create a LMMS plugin.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%if %{with crippled_stk}
%patch4 -p1
%endif
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

%build
mkdir build
cd build
export CFLAGS="%{optflags} -fgnu89-inline"
export CXXFLAGS="%{optflags}"
cmake -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DCMAKE_INSTALL_LIBDIR=%{_lib} \
      -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_VERBOSE_MAKEFILE=TRUE \
      ..
make %{?_smp_mflags}

%install
cd build
%make_install
cd ..
# Debian menu system
rm -r '%{buildroot}%{_datadir}/menu'
mkdir -p '%{buildroot}%{_defaultdocdir}/lmms/'
%fdupes -s %{buildroot}/%{_datadir}

%post
%icon_theme_cache_post
%mime_database_post
%desktop_database_post

%postun
%desktop_database_postun
%mime_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README TODO
%{_bindir}/lmms
%{_mandir}/man1/lmms.1*
%{_libdir}/lmms/
%{_datadir}/lmms/
%{_datadir}/applications/lmms.desktop
%{_datadir}/pixmaps/lmms.png
%{_datadir}/mime/packages/lmms.xml

%files devel
%defattr(0644,root,root,0755)
%{_includedir}/lmms/

%changelog
* Tue Oct 25 2016 stephan.barth@suse.com
- Added __requires_exclude_from to prevent RPM from adding a requirement for a
  library that only exists during build time (bsc#997249)
* Sat Jun 18 2016 olaf@aepfle.de
- Adjust indent to allow compile with gcc6 (bnc#985248)
  lmms-code-indent.patch
  lmms-code-macro.patch
  lmms-code-min.patch
* Thu Feb 25 2016 olaf@aepfle.de
- Use carla-standalone instead of Carla in pkgconfig
* Sat Jan 16 2016 edogawa@aon.at
- added support for internal Carla LV2/DSSI/VST plugin host
  * lmms-carla.patch: backported an upstream patch to implement NATIVE_HOST_OPCODE_HOST_IDLE
  * added falkTX's fix for lib/lib64 in the hardcoded carla plugin resource path so that they will find their GUIs
* Fri Jul  3 2015 olaf@aepfle.de
- Add versioned BuildRequires, adjust wine BuildRequires
* Wed Jun 24 2015 antoine.belvire@laposte.net
- Fix compilation with GCC 5:
  * Add lmms-1.1.3-fix-wrong-comparison-logic.patch from upstream.
  * Add fgnu89-inline to CFLAGS.
* Fri Mar 27 2015 stephan.barth@suse.com
- Reverted Source0 tag to the real download location
* Mon Mar  9 2015 stephan.barth@suse.com
- Update to version 1.1.3 from 1.1.0
  Upstream changes:
  - Fix pops and clicks introduced with new mixer (Bug #1662)
  - Fix 0%% export bug affecting certain languages/locales (Bug #1496)
  - Fix Watsyn shows wrong selection after switching instruments (Bug #1526)
  - Fix Nescaline crash when playing very high notes (Bug #1492)
  - Fix AudioFileProcessor wave display bug (Bug #929)
  - Fix various memory leaks
* Sun Feb 15 2015 devel.suse@gmail.com
- Change URL project link and some spec file changes
* Sat Feb 14 2015 reddwarf@opensuse.org
- Use real 1.1.0 tarball
  The previous commit used a random git commit, even if it said 1.1.0
- Revert back to lmms-1.0.0-crippled_stk.patch
- Remove precheckin_cripple_tarball.sh and related
  The real 1.1.0 tarball doesn't contain the problematic file anymore
- Update the Source tag with the new download URL
- lmms-1.1.0-return.patch keeps substituting lmms-1.0.0-return.patch
  Just to make the factory-auto script happy
* Fri Dec 26 2014 stephan.barth@suse.com
- Rebased crippled_stk.patch
  lmms-1.1.0-crippled_stk.patch
- Added more output to precheckin_cripple_tarball.sh
- Fixed lmms-1.1.0-return.patch. Only file location changed.
- Update to version 1.1.0
  Most interesting upstream changes:
  * New FX Mixer
  * New Instruments:
    + Nescaline - Nintendo Entertainment System(R) sound emulator
    + Watsyn - Advanced wavetable synth
    + Monstro - Advanced triple oscillator synth
    + Carla - Audio plugin host (Linux only)
  * Instrument Enhancements:
    + AudioFileProcessor - Adjustable loop points
    + Kicker - Temposyncable envelope, higher max; distortion enhancements
    + LB302 - Fix note sticking, playback bugs
  * UI Improvements
    + Piano Roll:
    Ctrl + Left/Right Arrow keys now moves selected notes by one bar
    Shift + Up/Down now moves selected notes by one semitone
  * Enabled toggling of knob scale in context menu (Linear/Logarithmic)
  * Added ability to record automations
  * Added support for undo/redo in Piano Roll
  * Bug Fixes
* Sat Aug  2 2014 stephan.barth@suse.com
- upgrade to version 1.0.3 from 1.0.2
  Relevant upstream changes:
  - Fix SF2 note volume
  - Localization updates
  - Updated LADSPA search paths
  - Bugfixes in plugins
* Mon Jun  2 2014 stephan.barth@suse.com
- reinstated full bcond if condition and added upstream URL back
- removed BuildRequires for portaudio-devel and sdl, because they are not
  needed.
* Fri May  9 2014 stephan.barth@suse.com
- update to version 1.0.2 which is bugfix release
* Fri May  2 2014 stephan.barth@suse.com
- update to version 1.0.0
- Added BuildRequires for wine to be still able to build the VST plugin
- Added explicit Requires for %%{_bindir}/wineserver which is needed for full
  VST support
- removed patches:
  - lmms-0.4.14-system_fltk.patch
    lmms now uses system fltk by itself
- redone patches:
  - lmms-1.0.0-crippled_stk.patch
  - lmms-1.0.0-return.patch
- added Requires for portaudio-devel and pkgconfig(sdl)
- updated precheckin_cripple_tarball.sh since the tarball name slightly
  changed
* Thu Aug  1 2013 reddwarf@opensuse.org
- Enable VST support in openSUSE 12.3 x86-64
* Wed Jun 12 2013 reddwarf@opensuse.org
- Update to 0.4.15
  * AutomationPattern: initialize with current value of first object
  * Chords: fixed major pentatonic
  * Properly cancel file export if opening output file failed
  * InstrumentTrack: fix freeze when forwarding MIDI events to instrument
  * Sf2Player: preserve custom track name when loading settings
  * AudioFileProcessor: make playback cursor configurable
  * AudioFileProcessor: fix crash with reversed samples
* Wed May  1 2013 reddwarf@opensuse.org
- Add lmms-0.4.14-system_fltk.patch.
- Stop building the portaudio and sdl audio backends. There is no
  need for wrappers when the real backends are directly supported.
- Remove one %%if. wine-32bit has never been a substitute for wine-devel-32bit.
- Use %%{_defaultdocdir} instead of {_datadir}/doc/packages
* Mon Apr 29 2013 stephan.barth@suse.com
- update to version 0.4.14 which is a maintainance release "with some exciting
  new features (notably regarding VST support)"
  Full upstream changelog can be found in
  /usr/share/doc/packages/lmms/releasenotes-0.4.14.txt
- removed the following patches because they have been applied upstream:
  - lmms-0.4.12-overflow.patch
  - lmms-0.4.13-gcc47.patch
- removed lmms-0.4.12-system_fltk.patch because the UI now fails to link with
  "undefined references" with the openSUSE fltk. Package now builds with fltk
  provided by its own tarball
* Tue Sep 11 2012 reddwarf@opensuse.org
- Recommend %%{_bindir}/wine, needed by the VST plugin
- Don't remove execute permission from VST and ZynAddSubFx plugins
- Don't remove rpath, it's needed by the ZynAddSubFx plugin
* Wed Aug 22 2012 dmueller@suse.com
- simply set libdir in the cmake call, which fixes build for ARM
* Mon Aug  6 2012 dvaleev@suse.com
- set libdir on powerpc correctly
* Wed May 16 2012 reddwarf@opensuse.org
- Fix build with openSUSE's crippled stk
* Tue May  8 2012 reddwarf@opensuse.org
- Add precheckin_cripple_tarball.sh logic (bnc#761147)
* Fri Apr 27 2012 reddwarf@opensuse.org
- Remove %%suse_update_desktop_file usage
- Add lmms-0.4.13-gcc47.patch
* Thu Mar  8 2012 reddwarf@opensuse.org
- Initial package
